==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Setări generale</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Setări generale OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>Executabil OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Import OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Folosire ViewProvider pentru vederea arborescenta</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Daca e bifat, obiectul Multimax va fi parametric</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Folositi caracteristica Multmatrix</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Numarul de fete a poligonului, prismei sau trunchiului. Daca fn este mai mare decat aceasta valoare obiectul este considerat circular. 0 inseamna ca nu exista nici o limita</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Numarul maxim de fete pentru poligoane (fn)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Export OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>marimea maxima a fragmentului</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>unghiular (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="../ui/openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>marime (fs)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>convex</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Retea de rezerva</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Deformarea</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>deformarea</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Setari pentru triangulatie</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Dacă această casuţă este bifată, componentele îşi vor însuşii copii în vizualizarea arbore</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Imprimaţi informaţii de depanare în consolă</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>Calea către executabilul OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Unghiul minim pentru un fragment</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Marimea minima a unui fragment</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="145"/>
      <source>Convert Edges to Faces</source>
      <translation>Convertiti marginile in fete</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="224"/>
      <source>Please select 3 objects first</source>
      <translation>Selectati mai intai 3 obiecte</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Unsupported Function</source>
      <translation>Functia nu este suportata</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Press OK</source>
      <translation>Apasati Ok</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="268"/>
      <source>Add</source>
      <translation>Adaugă</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="269"/>
      <source>Clear</source>
      <translation>Șterge</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="270"/>
      <source>as Mesh</source>
      <translation>o retea</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="271"/>
      <source>Add OpenSCAD Element</source>
      <translation>Adauga element OpenSCAD</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="344"/>
      <source>Perform</source>
      <translation>Efectuează</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="345"/>
      <source>Mesh Boolean</source>
      <translation>Plasă Boolean</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="585"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Eroare toate formele trebuie să fie fie 2D sau ambele trebuie să fie 3D</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="95"/>
      <source>Unable to explode %s</source>
      <translation>Nu se poate exploda %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="386"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Adauga element OpenSCAD...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="388"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Adauga u element OpenSCAD prin introducerea unui cod OpenSCAD si executarea codului binar</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="122"/>
      <source>Color Shapes</source>
      <translation>Forme de culoare</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="124"/>
      <source>Color Shapes by validity and type</source>
      <translation>Forme de culoare dupa validitate si tip</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="143"/>
      <source>Convert Edges To Faces</source>
      <translation>Conversie margini in fete</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="204"/>
      <source>Expand Placements</source>
      <translation>Amplasamente expandate</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="206"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Extinde toate amplasamentele mai jos de FeatureTree</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="104"/>
      <source>Explode Group</source>
      <translation>Explodare grup</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="106"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Scoateţi fusion, aplica plasarea copiilor şi culoare la întâmplare</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="421"/>
      <source>Hull</source>
      <translation>carenă</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="423"/>
      <source>Perform Hull</source>
      <translation>Efectuează Hull</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="185"/>
      <source>Increase Tolerance Feature</source>
      <translation>Crește funcția toleranței</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="187"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Creează o funcție care permite creșterea toleranței</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="400"/>
      <source>Mesh Boolean...</source>
      <translation>Ochiurilor de plasă Boolean...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="402"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Exporta obiectele ca plase şi de a folosi OpenSCAD pentru a efectua o operaţiune tip boolean</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="442"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="444"/>
      <source>Perform Minkowski</source>
      <translation>Efectuează Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="164"/>
      <source>Refine Shape Feature</source>
      <translation>Rafineaza caracteristica de forma</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="166"/>
      <source>Create Refine Shape Feature</source>
      <translation>Creaza rafinament de forma</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="243"/>
      <source>Remove Objects and their Children</source>
      <translation>Elimina obiectele si copii lor</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="245"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Elimina obiectele selectate si toti copiii care nu sunt referentiati de alte obiecte</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="228"/>
      <source>Replace Object</source>
      <translation>Inlocuieste obiectul</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="230"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Inlocuieste un obiect in FeatureTree. Selectati obiectul vechi, cel nou si obiectul parinte</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="../../InitGui.py" line="80"/>
      <source>OpenSCAD Part tools</source>
      <translation>Instrumente de OpenSCAD Part</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../InitGui.py" line="78"/>
      <source>OpenSCADTools</source>
      <translation>Unelte OpenSCAD</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="ro" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Setări generale</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Setări generale OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>Executabil OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Import OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Folosire ViewProvider pentru vederea arborescenta</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Daca e bifat, obiectul Multimax va fi parametric</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Folositi caracteristica Multmatrix</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Numarul de fete a poligonului, prismei sau trunchiului. Daca fn este mai mare decat aceasta valoare obiectul este considerat circular. 0 inseamna ca nu exista nici o limita</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Numarul maxim de fete pentru poligoane (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Export OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>marimea maxima a fragmentului</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>unghiular (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>marime (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>convex</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Retea de rezerva</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Deformarea</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>deformarea</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Setari pentru triangulatie</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Dacă această casuţă este bifată, componentele îşi vor însuşii copii în vizualizarea arbore</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Imprimaţi informaţii de depanare în consolă</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>Calea către executabilul OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Unghiul minim pentru un fragment</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Marimea minima a unui fragment</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="149"/>
      <source>Convert Edges to Faces</source>
      <translation>Convertiti marginile in fete</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="309"/>
      <source>Please select 3 objects first</source>
      <translation>Selectati mai intai 3 obiecte</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Unsupported Function</source>
      <translation>Functia nu este suportata</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Press OK</source>
      <translation>Apasati Ok</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="347"/>
      <source>Add</source>
      <translation>Adaugă</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="348"/>
      <source>Clear</source>
      <translation>Șterge</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="349"/>
      <source>as Mesh</source>
      <translation>o retea</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="350"/>
      <source>Add OpenSCAD Element</source>
      <translation>Adauga element OpenSCAD</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="423"/>
      <source>Perform</source>
      <translation>Efectuează</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="424"/>
      <source>Mesh Boolean</source>
      <translation>Plasă Boolean</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="623"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Eroare toate formele trebuie să fie fie 2D sau ambele trebuie să fie 3D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>Unable to explode %s</source>
      <translation>Nu se poate exploda %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="464"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Adauga element OpenSCAD...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="468"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Adauga u element OpenSCAD prin introducerea unui cod OpenSCAD si executarea codului binar</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="126"/>
      <source>Color Shapes</source>
      <translation>Forme de culoare</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="129"/>
      <source>Color Shapes by validity and type</source>
      <translation>Forme de culoare dupa validitate si tip</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="146"/>
      <source>Convert Edges To Faces</source>
      <translation>Conversie margini in fete</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="291"/>
      <source>Expand Placements</source>
      <translation>Amplasamente expandate</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="294"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Extinde toate amplasamentele mai jos de FeatureTree</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="110"/>
      <source>Explode Group</source>
      <translation>Explodare grup</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="113"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Scoateţi fusion, aplica plasarea copiilor şi culoare la întâmplare</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="497"/>
      <source>Hull</source>
      <translation>carenă</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="500"/>
      <source>Perform Hull</source>
      <translation>Efectuează Hull</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="274"/>
      <source>Increase Tolerance Feature</source>
      <translation>Crește funcția toleranței</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="277"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Creează o funcție care permite creșterea toleranței</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="477"/>
      <source>Mesh Boolean...</source>
      <translation>Ochiurilor de plasă Boolean...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="481"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Exporta obiectele ca plase şi de a folosi OpenSCAD pentru a efectua o operaţiune tip boolean</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="516"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="519"/>
      <source>Perform Minkowski</source>
      <translation>Efectuează Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="195"/>
      <source>Mirror Mesh Feature...</source>
      <translation>Funcția Reflectă Mesh...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="198"/>
      <source>Create Mirror Mesh Feature</source>
      <translation>Creează Funcția Reflectă Mesh</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="165"/>
      <source>Refine Shape Feature</source>
      <translation>Rafineaza caracteristica de forma</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="168"/>
      <source>Create Refine Shape Feature</source>
      <translation>Creaza rafinament de forma</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="324"/>
      <source>Remove Objects and their Children</source>
      <translation>Elimina obiectele si copii lor</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="327"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Elimina obiectele selectate si toti copiii care nu sunt referentiati de alte obiecte</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="312"/>
      <source>Replace Object</source>
      <translation>Inlocuieste obiectul</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="315"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Inlocuieste un obiect in FeatureTree. Selectati obiectul vechi, cel nou si obiectul parinte</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="254"/>
      <source>Resize Mesh Feature...</source>
      <translation>Redimensionează funcția Mesh...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="258"/>
      <source>Create Resize Mesh Feature</source>
      <translation>Crează funcția Redimensionare Mesh</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Scale Mesh Feature...</source>
      <translation>Funcția Redimensionează Mesh...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="228"/>
      <source>Create Scale Mesh Feature</source>
      <translation>Crează funcția Dimensionare Mesh</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="83"/>
      <source>OpenSCAD Part tools</source>
      <translation>Instrumente de OpenSCAD Part</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="81"/>
      <source>OpenSCADTools</source>
      <translation>Unelte OpenSCAD</translation>
    </message>
  </context>
</TS>
